pub enum InterpolationInsert {
Newest,
Late,
Replaced,
}Expand description
Result of inserting one remote state.
Variants
Newest
A state newer than every buffered Tick was inserted.
Late
A previously missing older Tick was inserted out of order.
Replaced
A duplicate Tick replaced its buffered state.