InterpolationConfig

Struct InterpolationConfig 

#[non_exhaustive]
pub struct InterpolationConfig { pub tick_rate: u32, pub capacity: usize, pub base_delay_ticks: f64, pub min_delay_ticks: f64, pub max_delay_ticks: f64, pub smoothing: f64, pub jitter_multiplier: f64, pub late_sample_penalty_ticks: f64, pub max_adjustment_per_sample_ticks: f64, }
Remote-state buffer and adaptive interpolation-delay parameters.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
tick_rate: u32

Authoritative server simulation frequency.

capacity: usize

Maximum remote states retained in Tick order.

base_delay_ticks: f64

Normal render delay before measured jitter or late arrivals are added.

min_delay_ticks: f64

Minimum adaptive render delay.

max_delay_ticks: f64

Maximum adaptive render delay.

smoothing: f64

Exponential smoothing weight for arrival jitter and late-sample pressure.

jitter_multiplier: f64

Number of additional delay ticks added per measured jitter Tick.

late_sample_penalty_ticks: f64

Maximum additional delay caused by repeatedly late samples.

max_adjustment_per_sample_ticks: f64

Maximum interpolation-delay movement after one newest-state observation.

Implementations

Source

impl InterpolationConfig

pub fn validate(&self) -> NetcodeResult<()>

Validates Tick, capacity, smoothing, and delay bounds.