pub struct InterpolationSample<'a, S> {
pub render_tick: f64,
pub previous_tick: u64,
pub previous: &'a S,
pub next_tick: u64,
pub next: &'a S,
pub alpha: f64,
pub holding_newest: bool,
}Expand description
Two buffered states and interpolation factor selected for rendering.
Fields
render_tick: f64Fractional server Tick selected for rendering.
previous_tick: u64Tick of the earlier state.
previous: &'a SEarlier state supplied to application interpolation.
next_tick: u64Tick of the later state.
next: &'a SLater state supplied to application interpolation.
alpha: f64Clamped blend factor between previous and next.
holding_newest: booltrue when rendering is ahead of the newest state and the newest state is held.