ReconciliationReport

Struct ReconciliationReport 

pub struct ReconciliationReport<S> {
    pub authoritative_tick: u64,
    pub predicted_state_at_authoritative_tick: Option<S>,
    pub corrected_state: S,
    pub replayed_inputs: usize,
    pub current_tick: u64,
}
Result of restoring an authoritative state and replaying unconfirmed inputs.

Fields

authoritative_tick: u64

Server Tick represented by the authoritative state.

predicted_state_at_authoritative_tick: Option<S>

Local predicted state previously recorded at the authoritative Tick, when retained.

corrected_state: S

Corrected present state after replaying every pending input.

replayed_inputs: usize

Number of unconfirmed inputs replayed.

current_tick: u64

Newest local predicted Tick after reconciliation.