#[non_exhaustive]pub struct TickSyncConfig {
pub tick_rate: u32,
pub input_delay_ticks: u64,
pub smoothing: f64,
pub max_round_trip_time: Duration,
pub max_offset_correction_ticks: f64,
}Expand description
Client-side Tick estimation limits.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.tick_rate: u32Authoritative server simulation frequency.
input_delay_ticks: u64Future input delay added after the estimated current server Tick.
smoothing: f64Exponential smoothing weight applied to each accepted sample in 0.0..=1.0.
max_round_trip_time: DurationLargest network round-trip duration accepted as a useful sample.
max_offset_correction_ticks: f64Largest Tick-offset correction accepted from one sample before smoothing.
Implementations
Sourceimpl TickSyncConfig
impl TickSyncConfig
Sourcepub fn validate(&self) -> NetcodeResult<()>
pub fn validate(&self) -> NetcodeResult<()>
Validates Tick rate, duration, and smoothing bounds.