pub struct ReconciliationReport<S> {
pub authoritative_tick: u64,
pub predicted_state_at_authoritative_tick: Option<S>,
pub corrected_state: S,
pub replayed_inputs: usize,
pub current_tick: u64,
}Expand description
Result of restoring an authoritative state and replaying unconfirmed inputs.
Fields
Server Tick represented by the authoritative state.
Local predicted state previously recorded at the authoritative Tick, when retained.
corrected_state: SCorrected present state after replaying every pending input.
replayed_inputs: usizeNumber of unconfirmed inputs replayed.
current_tick: u64Newest local predicted Tick after reconciliation.